.. py:currentmodule:: rubin_sim.selfcal

.. _rubin_sim.selfcal:

=================
rubin_sim selfcal
=================

Tools for simulating self-calibration.


Python API
==========

* :ref:`rubin_sim.selfcal api`

* :ref:`search`
